# 门户V2头部菜单第三方页面展示定制
![图 11](assets/portal-new-custom/2024-05-27-15-24-29-467.png)  

## 案例需求
基于平台，在头部新增菜单按钮，实现平台页面及第三方页面在内容区切换展示


## 知识点
1.门户平台首页头部菜单定制
2.实现平台首页及第三方页面切换展示

## 开发过程
1. 使用租户管理员登录系统，在“**应用/服务管理**”新增企业门户V2，开启门户定制（详细操作步骤可参考 **[门户V2调试](./portal-new-debug.md "门户V2调试,开启门户定制")**）

2. 进入云端开发后，找到市场组件“**门户自定义**”，并开启组件**定制** 
![图 9](assets/2024-03-26-17-34-59-765.png)  

3. 进入到“代码”模块下，在“\UI2\comp\portalConfig\components\portalConfig”组件目录下，对“**portalConfig.config.js**”（文件命名：组件名+“.config.js”，**不能随便定义**）进行定制编辑,文件基础内容如下所示：
```
import { merge } from "lodash";
import ConfigContextProcessor from 'core/framework/ConfigContextProcessor';
import React from 'react';

export default {

    processConfigContext(configContext) {
    },

    //自定义
    async onConfigContextInit(configContextProcessor) {
        //获取当前页
        let _this = configContextProcessor.page;

        //自定义菜单点击事件
        const headerMenuClick=(e)=>{           
            let data=e.currentTarget.getAttribute("data");
            //iframe元素
            let framePage=document.getElementById("framePgae");
            //原平台菜单及内容元素
            let layoutPage=document.querySelectorAll("#layoutPage .uix-portal-layout-content,#layoutPage .uix-portal-sider");
            if(data=="home"){
                framePage.style.setProperty("display","none");
                layoutPage.forEach(item=>item.style.setProperty("display","initial"));
            }else{
                framePage.src=data;
                framePage.style.setProperty("display","initial");
                layoutPage.forEach(item=>item.style.setProperty("display","none"));
            }
        }

        //按照需要处理的文件路径及方法进行自定义
        //@after:方法执行后执行；参数：(result,...args),其中result是方法返回数据，args是原方法自带参数
        //@before:方法执行前执行;参数：(...args)，其中args是原方法自带参数
        //@replace:替换原方法;参数：(...args)，其中args是原方法自带参数
        //注意：上述3中方法，async标识必须与原方法同步，即原方法是异步，现在自定义方法才能使用异步，否则不能使用
        //详细使用案例可以参考“帮助中心”下门户v2定制下相关案例
        let portalConfig = {
            "config": {
                "/entry": {
                    "/pcxapp": {
                        "/pcx": {
                            "/index.w": {
                                "layoutRender": {
                                    //在原页面布局基础上新增iframe元素，用于展示第三方页面内容
                                    "@after": (result,...args) => {                                        
                                        return <>
                                            <iframe id="framePgae" frameborder="0" style={{display:"none",position:"fixed",top:"56px",width:"100%",height:"calc(100vh - 56px)",bottom:"0px",zIndex:1}}></iframe>
                                            <div id="layoutPage">{result}</div>
                                        </>;
                                    }
                                },
                                "headerActionsRender":{
                                    //在平台首页新增头部菜单按钮
                                    "@after":(result,...args)=>{                                        
                                        let hmenus=result;
                                        hmenus.unshift(<span onClick={headerMenuClick} data="https://news.sina.com.cn/">sina</span>);
                                        hmenus.unshift(<span onClick={headerMenuClick} data="https://163.com">163</span>);
                                        hmenus.unshift(<span onClick={headerMenuClick} data="home">工作台</span>);
                                        return hmenus;
                                    }
                                }
                            }
                        }
                    }
                }
            }
        };
        //处理自定义内容
        merge(_this.configContext, portalConfig);
        ConfigContextProcessor.enhancePageAdvice(_this);
    }
}
```
4. “**门户自定义**”组件定制完成之后，重新发布即可